'use strict';

const tslib = require('tslib');
const common = require('@graphql-cli/common');
const graphqlCliCommon = require('@graphql-inspector/graphql-cli-common');
const introspectCommand = require('@graphql-inspector/introspect-command');

const index = common.defineCommand((api) => {
    const { loadSchema } = api.useLoaders({ loaders: graphqlCliCommon.loaders });
    return {
        command: 'introspect [project]',
        describe: 'Introspect a schema',
        builder(yargs) {
            return yargs
                .positional('project', {
                describe: 'Point to a project or schema',
                type: 'string',
            })
                .options({
                write: {
                    alias: 'w',
                    describe: 'Write to a file',
                    type: 'string',
                },
                comments: {
                    describe: 'Use preceding comments as the description',
                    type: 'boolean',
                },
                require: {
                    alias: 'r',
                    describe: 'Require modules',
                    type: 'array',
                },
                token: {
                    alias: 't',
                    describe: 'Access Token',
                    type: 'string',
                },
                header: {
                    alias: 'h',
                    describe: 'Http Header',
                    type: 'array',
                },
                config: {
                    alias: 'c',
                    type: 'string',
                    describe: 'Location of GraphQL Config',
                },
            })
                .default('w', 'graphql.schema.json');
        },
        handler(args) {
            return tslib.__awaiter(this, void 0, void 0, function* () {
                const { headers, token } = graphqlCliCommon.parseGlobalArgs(args);
                const output = args.write;
                const comments = args.comments || false;
                const config = yield api.useConfig({
                    rootDir: args.config || process.cwd(),
                    extensions: [graphqlCliCommon.createInspectorExtension('introspect')],
                });
                const project = config.projects[args.project || 'default'];
                const schema = yield (project
                    ? project.getSchema()
                    : loadSchema(args.project, {
                        headers,
                        token,
                    }));
                return introspectCommand.handler({ schema, output, comments });
            });
        },
    };
});

module.exports = index;
//# sourceMappingURL=index.cjs.js.map
