import { __awaiter } from 'tslib';
import { defineCommand } from '@graphql-cli/common';
import { loaders, parseGlobalArgs, createInspectorExtension } from '@graphql-inspector/graphql-cli-common';
import { handler } from '@graphql-inspector/introspect-command';

const index = defineCommand((api) => {
    const { loadSchema } = api.useLoaders({ loaders });
    return {
        command: 'introspect [project]',
        describe: 'Introspect a schema',
        builder(yargs) {
            return yargs
                .positional('project', {
                describe: 'Point to a project or schema',
                type: 'string',
            })
                .options({
                write: {
                    alias: 'w',
                    describe: 'Write to a file',
                    type: 'string',
                },
                comments: {
                    describe: 'Use preceding comments as the description',
                    type: 'boolean',
                },
                require: {
                    alias: 'r',
                    describe: 'Require modules',
                    type: 'array',
                },
                token: {
                    alias: 't',
                    describe: 'Access Token',
                    type: 'string',
                },
                header: {
                    alias: 'h',
                    describe: 'Http Header',
                    type: 'array',
                },
                config: {
                    alias: 'c',
                    type: 'string',
                    describe: 'Location of GraphQL Config',
                },
            })
                .default('w', 'graphql.schema.json');
        },
        handler(args) {
            return __awaiter(this, void 0, void 0, function* () {
                const { headers, token } = parseGlobalArgs(args);
                const output = args.write;
                const comments = args.comments || false;
                const config = yield api.useConfig({
                    rootDir: args.config || process.cwd(),
                    extensions: [createInspectorExtension('introspect')],
                });
                const project = config.projects[args.project || 'default'];
                const schema = yield (project
                    ? project.getSchema()
                    : loadSchema(args.project, {
                        headers,
                        token,
                    }));
                return handler({ schema, output, comments });
            });
        },
    };
});

export default index;
//# sourceMappingURL=index.esm.js.map
